<?php

namespace Drupal\click_a_role\Form;

use Drupal\Core\Form\ConfigFormBase;
use Drupal\Core\Form\FormStateInterface;
use Drupal\user\Entity\Role;

/**
 * Configure Click a role settings form.
 */
class ClickARoleSettingsForm extends ConfigFormBase {

  /**
   * Config settings.
   *
   * @var string
   */
  const SETTINGS = 'click_a_role.settings';

  /**
   * {@inheritdoc}
   */
  public function getFormId() {
    return 'click_a_role_settings_form';
  }

  /**
   * {@inheritdoc}
   */
  protected function getEditableConfigNames() {
    return [
      static::SETTINGS,
    ];
  }

  /**
   * {@inheritdoc}
   */
  public function buildForm(array $form, FormStateInterface $form_state) {
    $config = $this->config(static::SETTINGS);

    $roles = Role::loadMultiple();
    $options = array();
    foreach($roles as $role) {
      $options[$role->id()] = $role->get('label');
    }

    $form['roles'] = [
      '#type' => 'select',
      '#multiple' => true,
      '#title' => $this->t('Select roles users are allowed to gain'),
      '#options' => $options,
      '#default_value' => $config->get('roles')
    ];

    return parent::buildForm($form, $form_state);
  }

  /**
   * {@inheritdoc}
   */
  public function submitForm(array &$form, FormStateInterface $form_state) {
    // Retrieve the configuration.
    $this->configFactory->getEditable(static::SETTINGS)
      // Set the selected roles setting.
      ->set('roles', $form_state->getValue('roles'))
      ->save();
    parent::submitForm($form, $form_state);
  }
}
